# Glean JavaScript SDK

The Glean JavaScript SDK allows integration with three distinct JavaScript environments: websites,
web extension and Node.js.

It is available as [`@mozilla/glean` on npm](https://www.npmjs.com/package/@mozilla/glean).
This package has different entry points to access the different SDKs.

- `@mozilla/glean/web` gives access to the websites SDK
- `@mozilla/glean/webext` gives access to the web extension SDK
- `@mozilla/glean/node` gives access to the Node.js SDK
